/// <reference types="react" />
import type { CheckboxProps, PaginationProps as TablePaginationConfig } from 'antd';
import type { RenderedCell, ColumnType as ExColumnType, GetRowKey } from '../../ExperimentTable';
export { GetRowKey, TablePaginationConfig };
export declare type ArtTableContextType = {
    manager: ArtTableManager;
};
export declare type Key = React.Key;
export declare type RowSelectionType = 'checkbox' | 'radio';
export declare type SizeType = 'small' | 'middle' | 'large';
export declare type TableAction = 'pagination' | 'filter' | 'sort' | 'fieldConfig' | 'lineHeight' | 'globalShow' | 'column' | 'tableScroll';
export declare type Identifier = string | number;
export declare type ActionCreator<Payload> = (args: any[]) => Action<Payload>;
export interface Action<Payload> {
    type: Identifier;
    payload: Payload;
}
export interface ArtTableManager {
    getStore(): any;
    getState(): any;
    getActions(): any;
    dispatch(action: any): void;
}
export interface TableCurrentDataSource<RecordType> {
    currentDataSource: RecordType[];
    action: TableAction;
}
export declare type TransformColumns<RecordType> = (columns: ColumnsType<RecordType>) => ColumnsType<RecordType>;
export declare type SelectionSelectFn<T> = (record: T, selected: boolean, selectedRows: T[], nativeEvent: Event) => void;
export declare type SelectionItemSelectFn = (currentRowKeys: Key[]) => void;
export interface SelectionItem {
    key: string;
    text: React.ReactNode;
    onSelect?: SelectionItemSelectFn;
}
export interface TableRowSelection<T> {
    /** Keep the selection keys in list even the key not exist in `dataSource` anymore */
    preserveSelectedRowKeys?: boolean;
    type?: RowSelectionType;
    selectedRowKeys?: Key[];
    defaultSelectedRowKeys?: Key[];
    onChange?: (selectedRowKeys: Key[], selectedRows: T[]) => void;
    getCheckboxProps?: (record: T) => Partial<Omit<CheckboxProps, 'checked' | 'defaultChecked'>>;
    onSelect?: SelectionSelectFn<T>;
    onSelectMultiple?: (selected: boolean, selectedRows: T[], changeRows: T[]) => void;
    /** @deprecated This function is meaningless and should use `onChange` instead */
    onSelectAll?: (selected: boolean, selectedRows: T[], changeRows: T[]) => void;
    /** @deprecated This function is meaningless and should use `onChange` instead */
    hideSelectAll?: boolean;
    columnWidth?: string | number;
    columnTitle?: string | React.ReactNode;
    checkStrictly?: boolean;
    renderCell?: (value: boolean, record: T, index: number, originNode: React.ReactNode) => React.ReactNode | RenderedCell<T>;
}
export interface FilterProps {
    field?: boolean;
}
export interface ColumnTitleProps {
    filter?: Record<string, string[]>;
    onColumnChange?: any;
    onResizeStart?: any;
    onResizeStop?: any;
}
export declare type ColumnTitle = React.ReactNode | ((props: ColumnTitleProps) => React.ReactNode);
export interface ColumnType<RecordType> extends ExColumnType<RecordType> {
    title?: ColumnTitle;
    textTitle?: string;
    icon?: React.ReactNode | ((props: ColumnTitleProps) => React.ReactNode);
    filter?: any;
    resize?: any;
    sortable?: any;
    flex?: boolean;
    hiddenColumnConfig?: boolean;
    fieldType?: string;
    sort?: {
        type: 'az' | '09' | 'zf';
        isDefault: boolean;
        /**
         * 如果是默认规则,则order会代替顺序进行排序
         */
        order?: number;
    };
}
export interface ColumnGroupType<RecordType> extends Omit<ColumnType<RecordType>, 'dataIndex'> {
    children: ColumnsType<RecordType>;
}
export declare type ColumnsType<RecordType = unknown> = (ColumnGroupType<RecordType> | ColumnType<RecordType>)[];
export declare type FilterValue = (Key | boolean)[];
export declare type FilterKey = Key[] | null;
