function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import _ from 'lodash';
import Cell from '../Cell';
import TableContext from '../context/TableContext';
import BodyContext from '../context/BodyContext';
import { getColumnsKey, getCellWidth, parseHeaderRows } from '../utils/valueUtil';

function BodyRow(props) {
  var _getExtraState;

  var className = props.className,
      style = props.style,
      record = props.record,
      renderIndex = props.renderIndex,
      rowKey = props.rowKey,
      onRow = props.onRow,
      onCell = props.onCell,
      _props$indent = props.indent,
      indent = _props$indent === void 0 ? 0 : _props$indent;

  var _React$useContext = React.useContext(TableContext),
      prefixCls = _React$useContext.prefixCls,
      fixedInfoList = _React$useContext.fixedInfoList,
      getExtraState = _React$useContext.getExtraState,
      selectedColor = _React$useContext.selectedColor,
      cellExtraRender = _React$useContext.cellExtraRender;

  var _React$useContext2 = React.useContext(BodyContext),
      flattenColumns = _React$useContext2.flattenColumns,
      rowClassName = _React$useContext2.rowClassName; // =========================== onRow ===========================


  var additionalProps = onRow === null || onRow === void 0 ? void 0 : onRow(record, renderIndex);

  var onClick = function onClick(event) {
    var _additionalProps$onCl;

    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    additionalProps === null || additionalProps === void 0 ? void 0 : (_additionalProps$onCl = additionalProps.onClick) === null || _additionalProps$onCl === void 0 ? void 0 : _additionalProps$onCl.call.apply(_additionalProps$onCl, [additionalProps, event].concat(args));
  }; // ======================== Base tr row ========================


  var computeRowClassName;

  if (typeof rowClassName === 'string') {
    computeRowClassName = rowClassName;
  } else if (typeof rowClassName === 'function') {
    computeRowClassName = rowClassName(record, renderIndex, indent);
  }

  var columnsKey = getColumnsKey(flattenColumns);
  var colWidths = flattenColumns.map(function (_ref) {
    var width = _ref.width;
    return width;
  });
  var rows = React.useMemo(function () {
    return parseHeaderRows(flattenColumns);
  }, [flattenColumns]);
  var selectedCell = (_getExtraState = getExtraState()) === null || _getExtraState === void 0 ? void 0 : _getExtraState.selectedCell;
  var isSelectedRow = (selectedCell === null || selectedCell === void 0 ? void 0 : selectedCell.rowIndex) === renderIndex;
  var baseRowNode = /*#__PURE__*/React.createElement("div", _objectSpread(_objectSpread({}, additionalProps), {}, {
    "data-row-key": rowKey,
    className: classNames(className, "".concat(prefixCls, "-row"), "".concat(prefixCls, "-row-level-").concat(indent), computeRowClassName, additionalProps && additionalProps.className),
    style: _objectSpread(_objectSpread({
      display: 'flex',
      backgroundColor: isSelectedRow ? selectedColor : 'transparent'
    }, style), additionalProps ? additionalProps.style : null),
    onClick: onClick
  }), flattenColumns.map(function (column, colIndex) {
    var render = column.render,
        dataIndex = column.dataIndex,
        columnClassName = column.className;
    var key = columnsKey[colIndex];
    var fixedInfo = fixedInfoList[colIndex]; // ============= Used for extra =============

    var appendCellNode;
    var additionalCellProps;

    if (column.onCell) {
      additionalCellProps = column === null || column === void 0 ? void 0 : column.onCell(record, renderIndex, colIndex); // 根据虚拟列表进行index校准
    }

    var beginRow = rows[0][colIndex];
    var cellWidth = getCellWidth(beginRow.colStart, beginRow.colSpan, colWidths);
    var isSelectedCell = isSelectedRow && (selectedCell === null || selectedCell === void 0 ? void 0 : selectedCell.columnIndex) === colIndex || (selectedCell === null || selectedCell === void 0 ? void 0 : selectedCell.rowIndex) < 0 && (selectedCell === null || selectedCell === void 0 ? void 0 : selectedCell.columnIndex) === colIndex;
    /**
     * 业务额外渲染
     */

    var extraRender = !_.isUndefined(cellExtraRender) && (cellExtraRender === null || cellExtraRender === void 0 ? void 0 : cellExtraRender.index) === colIndex ? cellExtraRender === null || cellExtraRender === void 0 ? void 0 : cellExtraRender.render : null;

    if (!_.isNull(extraRender)) {
      appendCellNode = /*#__PURE__*/React.createElement(React.Fragment, null, extraRender(record, renderIndex, colIndex));
    }

    return /*#__PURE__*/React.createElement(Cell, _objectSpread(_objectSpread({
      cellWidth: cellWidth,
      className: columnClassName,
      ellipsis: column.ellipsis,
      align: column.align,
      prefixCls: prefixCls,
      key: key,
      record: record,
      index: renderIndex,
      columnIndex: colIndex,
      renderIndex: renderIndex,
      dataIndex: dataIndex,
      render: render,
      shouldCellUpdate: column.shouldCellUpdate
    }, fixedInfo), {}, {
      appendNode: appendCellNode,
      onCellClick: function onCellClick(event) {
        var _onCell;

        (_onCell = onCell(record, renderIndex, colIndex)) === null || _onCell === void 0 ? void 0 : _onCell.onClick(event); // 根据虚拟列表进行index校准
      },
      isFocusSelected: isSelectedRow && (selectedCell === null || selectedCell === void 0 ? void 0 : selectedCell.columnIndex) === colIndex,
      isSelectedCell: isSelectedCell || isSelectedRow,
      additionalProps: _objectSpread(_objectSpread({}, additionalCellProps), {}, {
        style: {
          flex: (column === null || column === void 0 ? void 0 : column.flex) === false ? '0 0 auto' : '1 0 auto',
          minWidth: (column === null || column === void 0 ? void 0 : column.minWidth) || 96
        }
      })
    }));
  }));
  return /*#__PURE__*/React.createElement(React.Fragment, null, baseRowNode);
}

BodyRow.displayName = 'BodyRow';
export default BodyRow;