import React from 'react';
import type { DefaultRecordType, ColumnType, CellEllipsisType, AlignType, DataIndex, CustomizeComponent } from '../types';
import type { HoverContextProps } from '../context/HoverContext';
interface InternalCellProps<RecordType extends DefaultRecordType> extends Pick<HoverContextProps, 'onHover'> {
    prefixCls?: string;
    _classNames?: any;
    className?: string;
    cellWidth?: any;
    record?: RecordType;
    index?: number;
    /** the index of the record. For the render(value, record, renderIndex, colIndex) */
    renderIndex?: number;
    columnIndex?: number;
    dataIndex?: DataIndex;
    render?: ColumnType<RecordType>['render'];
    summaryRender?: ColumnType<RecordType>['summaryRender'];
    children?: React.ReactNode;
    component?: CustomizeComponent;
    colSpan?: number;
    rowSpan?: number;
    ellipsis?: CellEllipsisType;
    align?: AlignType;
    shouldCellUpdate?: (record: RecordType, prevRecord: RecordType) => boolean;
    onCellClick?: any;
    isSelectedCell?: boolean;
    /**
     * 绝对定位选中单元格
     */
    isFocusSelected?: boolean;
    fixLeft?: number | false;
    fixRight?: number | false;
    firstFixLeft?: boolean;
    lastFixLeft?: boolean;
    firstFixRight?: boolean;
    lastFixRight?: boolean;
    /** @private Used for `expandable` with nest tree */
    appendNode?: React.ReactNode;
    additionalProps?: React.TdHTMLAttributes<HTMLTableCellElement>;
    /** @private Fixed for user use `shouldCellUpdate` which block the render */
    expanded?: boolean;
    rowType?: 'header' | 'body' | 'footer';
    isSticky?: boolean;
    isFooter?: boolean;
    hovering?: boolean;
}
export declare type CellProps<RecordType extends DefaultRecordType> = Omit<InternalCellProps<RecordType>, keyof HoverContextProps>;
/** Inject hover data here, we still wish MemoCell keep simple `shouldCellUpdate` logic */
declare const WrappedCell: React.ForwardRefExoticComponent<Pick<any, string | number | symbol> & React.RefAttributes<any>>;
export default WrappedCell;
