function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useEffect, useState, useRef } from 'react';
import classNames from 'classnames';
import { isMouseEvent, isTouchEvent } from '../utils/resizeUtil';

var ResizeableTitle = function ResizeableTitle(props) {
  var cellPrefixCls = props.cellPrefixCls,
      className = props.className,
      onResizeStart = props.onResizeStart,
      onResizeStop = props.onResizeStop,
      setIsHoverResize = props.setIsHoverResize,
      pKey = props.pKey,
      setIsColumnResize = props.setIsColumnResize,
      offsetLeft = props.offsetLeft,
      isColumnResize = props.isColumnResize;

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      deltaX = _useState2[0],
      setDeltaX = _useState2[1];

  var _useState3 = useState(0),
      _useState4 = _slicedToArray(_useState3, 2),
      clientX = _useState4[0],
      setClientX = _useState4[1];

  var _useState5 = useState(0),
      _useState6 = _slicedToArray(_useState5, 2),
      columnWidth = _useState6[0],
      setColumnWidth = _useState6[1];

  var resizeRef = useRef();
  var columnClassName = ".".concat(cellPrefixCls, "-").concat(pKey);

  var onMouseDown = function onMouseDown(event) {
    var _document$querySelect;

    setIsColumnResize(true);
    setDeltaX(0); // event.persist();

    var parentRect = (_document$querySelect = document.querySelector(columnClassName)) === null || _document$querySelect === void 0 ? void 0 : _document$querySelect.getBoundingClientRect();
    setColumnWidth((parentRect === null || parentRect === void 0 ? void 0 : parentRect.width) || 0);

    if (event.nativeEvent && isMouseEvent(event.nativeEvent)) {
      setClientX(event.nativeEvent.clientX);
    } else if (event.nativeEvent && isTouchEvent(event.nativeEvent)) {
      setClientX(event.nativeEvent.touches[0].clientX);
    }

    onResizeStart(pKey);
  };

  var onMouseMove = function onMouseMove(event) {
    if (isColumnResize) {
      if (window.TouchEvent && isTouchEvent(event)) {
        try {
          event.preventDefault();
          event.stopPropagation();
        } catch (e) {// Ignore on fail
        }
      }

      var _clientX = isTouchEvent(event) ? event.touches[0].clientX : event.clientX;

      var _deltaX = _clientX - clientX || 0;

      setDeltaX(_deltaX);
    }
  };

  var onMouseUp = function onMouseUp() {
    if (isColumnResize) {
      setIsColumnResize(false);
      onResizeStop(deltaX + columnWidth, pKey);
      setDeltaX(0);
      setClientX(0);
    }

    setIsHoverResize(false);
  };

  useEffect(function () {
    if (window) {
      window.addEventListener('mousemove', onMouseMove);
      window.addEventListener('touchmove', onMouseMove, {
        capture: true,
        passive: false
      });
      window.addEventListener('mouseup', onMouseUp);
      window.addEventListener('mouseleave', onMouseUp);
    }

    return function () {
      if (window) {
        window.removeEventListener('mousemove', onMouseMove);
        window.removeEventListener('touchmove', onMouseMove, true);
        window.removeEventListener('mouseup', onMouseUp);
        window.removeEventListener('mouseleave', onMouseUp);
      }
    };
  });
  return /*#__PURE__*/React.createElement("div", {
    onMouseLeave: function onMouseLeave() {
      if (!isColumnResize) {
        setIsHoverResize(false);
      }
    },
    onMouseDown: onMouseDown,
    onTouchStart: onMouseDown,
    onMouseUp: onMouseUp,
    className: classNames("".concat(className)),
    ref: resizeRef,
    style: {
      left: offsetLeft + deltaX
    }
  });
};

export default ResizeableTitle;