import React from 'react';
import type { ColumnsType, ColumnType, GetRowKey, GetComponentProps, GetCellComponentProps, DefaultRecordType, RowClassName } from './types';
import './style/index.less';
export declare function isVisible(element: any): boolean;
export interface TableProps<RecordType = unknown> {
    prefixCls?: string;
    className?: string;
    style?: React.CSSProperties;
    children?: React.ReactNode;
    data?: readonly RecordType[];
    columns?: ColumnsType<RecordType>;
    rowKey?: string | GetRowKey<RecordType>;
    rowClassName?: string | RowClassName<RecordType>;
    itemHeight?: number;
    summaryHeight?: number;
    scroll?: {
        x?: number | true | string;
        y?: number | string;
    };
    id?: string;
    onCell?: GetCellComponentProps<RecordType>;
    onRow?: GetComponentProps<RecordType>;
    onHeaderCell?: GetCellComponentProps<RecordType>;
    onHeaderRow?: GetComponentProps<readonly ColumnType<RecordType>[]>;
    onSummaryRow?: GetComponentProps<readonly ColumnType<RecordType>[]>;
    emptyText?: React.ReactNode | (() => React.ReactNode);
    onScrollbarStart?: () => void;
    onScrollbarStop?: () => void;
    onColumnResizeStart?: (key: string) => void;
    onColumnResizeStop?: (width: any, key: string) => void;
    isInfiniteLoader?: boolean;
    selectedColor?: any;
    direction?: 'ltr' | 'rtl';
    transformColumns?: (columns: ColumnsType<RecordType>) => ColumnsType<RecordType>;
    /**
     * 一系列特殊渲染,用于满足业务需求
     */
    cellExtraRender?: {
        index: number;
        render: (record: RecordType, index: number, columnIndex: number) => React.ReactNode;
    };
    /**
     * 用来扩展传递给cell的额外数据
     */
    getExtraState?: any;
    internalRefs?: {
        container: React.MutableRefObject<HTMLDivElement>;
        body: React.MutableRefObject<HTMLDivElement>;
        bodyInner: React.MutableRefObject<HTMLDivElement>;
    };
}
declare function Table<RecordType extends DefaultRecordType>(props: TableProps<RecordType>): JSX.Element;
declare namespace Table {
    var defaultProps: {
        rowKey: string;
        prefixCls: string;
        onColumnResizeStart: () => void;
        onColumnResizeStop: () => void;
        emptyText: () => string;
    };
}
export default Table;
