function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useEffect } from 'react';
import classNames from 'classnames';
import ResizeObserver from 'rc-resize-observer';
import shallowEqual from 'shallowequal';
import _ from 'lodash';
import { useDeepCompareEffect } from 'ahooks';
import Scrollbar from './Scrollbar';
import useSortable from './hooks/useSortable';
import useColumns from './hooks/useColumns';
import { useTimeoutLock, useLayoutState } from './hooks/useFrame';
import useStickyOffsets from './hooks/useStickyOffsets';
import useSticky from './hooks/useSticky';
import { getColumnsKey, validateValue } from './utils/valueUtil';
import { getCellFixedInfo } from './utils/fixUtil';
import FixedHolder from './FixedHolder';
import FixedHolderLine from './FixedHolder/FixedHolderLine';
import Header from './Header/Header';
import TableContext from './context/TableContext';
import BodyContext from './context/BodyContext';
import ExtraRowContext from './context/ExtraRowContext';
import ResizeContext from './context/ResizeContext';
import Body from './Body';
import ExtraRow from './Body/ExtraRow';
import Footer from './Footer';
import "./style/index.css";
import pickAttrs from './utils/pickAttrs';
export function isVisible(element) {
  if (!element) {
    return false;
  }

  if (element instanceof HTMLElement && element.offsetParent) {
    return true;
  }

  if (element instanceof SVGGraphicsElement && element.getBBox) {
    var _element$getBBox = element.getBBox(),
        width = _element$getBBox.width,
        height = _element$getBBox.height;

    if (width || height) {
      return true;
    }
  }

  if (element instanceof HTMLElement && element.getBoundingClientRect) {
    var _element$getBoundingC = element.getBoundingClientRect(),
        _width = _element$getBoundingC.width,
        _height = _element$getBoundingC.height;

    if (_width || _height) {
      return true;
    }
  }

  return false;
}
var EMPTY_DATA = []; // Used for customize scroll

var EMPTY_SCROLL_TARGET = {};
var MemoTableContent = /*#__PURE__*/React.memo(function (_ref) {
  var children = _ref.children;
  return children;
}, function (prev, next) {
  if (!shallowEqual(prev.props, next.props)) {
    return false;
  } // No additional render when pinged status change.
  // This is not a bug.


  return prev.pingLeft !== next.pingLeft || prev.pingRight !== next.pingRight;
});

function Table(props) {
  var _classNames;

  var prefixCls = props.prefixCls,
      className = props.className,
      style = props.style,
      data = props.data,
      rowKey = props.rowKey,
      scroll = props.scroll,
      direction = props.direction,
      id = props.id,
      emptyText = props.emptyText,
      onCell = props.onCell,
      onRow = props.onRow,
      onHeaderCell = props.onHeaderCell,
      onHeaderRow = props.onHeaderRow,
      onSummaryRow = props.onSummaryRow,
      rowClassName = props.rowClassName,
      onScrollbarStart = props.onScrollbarStart,
      onScrollbarStop = props.onScrollbarStop,
      onColumnResizeStart = props.onColumnResizeStart,
      onColumnResizeStop = props.onColumnResizeStop,
      selectedColor = props.selectedColor,
      itemHeight = props.itemHeight,
      summaryHeight = props.summaryHeight,
      cellExtraRender = props.cellExtraRender,
      getExtraState = props.getExtraState,
      transformColumns = props.transformColumns,
      internalRefs = props.internalRefs;
  var mergedData = data || EMPTY_DATA;
  var hasData = !!mergedData.length;
  var getRowKey = React.useMemo(function () {
    if (typeof rowKey === 'function') {
      return rowKey;
    }

    return function (record) {
      var key = record && record[rowKey];

      if (process.env.NODE_ENV !== 'production' && key === undefined) {
        console.error('Each record in table should have a unique `key` prop, or set `rowKey` to an unique primary key.');
      }

      return key;
    };
  }, [rowKey]); // ====================== virtual list ======================

  var _React$useState = React.useState({
    list: [],
    lastStartIndex: 0
  }),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      showData = _React$useState2[0],
      setShowData = _React$useState2[1];

  var lastStartIndex = React.useRef(null);
  var lastEndIndex = React.useRef(null);
  var viewMaxNum = React.useRef(null);
  var viewMaxHeight = React.useRef(0);
  var blankFill = React.useRef(null); // const viewTotal = React.useRef(data?.length || 0);
  // ====================== sortable =======================

  var _useSortable = useSortable(),
      _useSortable2 = _slicedToArray(_useSortable, 2),
      sortableStore = _useSortable2[0],
      sortableDispatch = _useSortable2[1]; // ====================== Column ======================


  var _React$useState3 = React.useState(0),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      componentWidth = _React$useState4[0],
      setComponentWidth = _React$useState4[1];

  var _useColumns = useColumns(_objectSpread(_objectSpread({}, props), {}, {
    getRowKey: getRowKey,
    direction: direction
  }), transformColumns),
      _useColumns2 = _slicedToArray(_useColumns, 2),
      columns = _useColumns2[0],
      flattenColumns = _useColumns2[1];

  var columnContext = React.useMemo(function () {
    return {
      columns: columns,
      flattenColumns: flattenColumns
    };
  }, [columns, flattenColumns]); // ====================== Scroll ======================

  var fullTableRef = React.useRef(); // const scrollLineRef = React.useRef<any>();

  var scrollHeaderRef = React.useRef();
  var scrollBodyRef = React.useRef();
  var bodyInnerRef = React.useRef();
  var scrollBodyContainerRef = React.useRef();
  var scrollSummaryRef = React.useRef();

  var _React$useState5 = React.useState(false),
      _React$useState6 = _slicedToArray(_React$useState5, 2),
      pingedLeft = _React$useState6[0],
      setPingedLeft = _React$useState6[1];

  var _React$useState7 = React.useState(false),
      _React$useState8 = _slicedToArray(_React$useState7, 2),
      pingedRight = _React$useState8[0],
      setPingedRight = _React$useState8[1];

  var _useLayoutState = useLayoutState(new Map()),
      _useLayoutState2 = _slicedToArray(_useLayoutState, 2),
      colsWidths = _useLayoutState2[0],
      updateColsWidths = _useLayoutState2[1]; // Convert map to number width


  var colsKeys = getColumnsKey(flattenColumns);
  var pureColWidths = colsKeys.map(function (columnKey) {
    return colsWidths.get(columnKey);
  });
  var colWidths = React.useMemo(function () {
    return pureColWidths;
  }, [pureColWidths.join('_')]);
  var stickyOffsets = useStickyOffsets(colWidths, flattenColumns.length, direction);
  var fixHeader = scroll && validateValue(scroll.y);
  var horizonScroll = scroll && validateValue(scroll.x);
  var fixColumn = horizonScroll && flattenColumns.some(function (_ref2) {
    var fixed = _ref2.fixed;
    return fixed;
  }); // Sticky

  var stickyRef = React.useRef();

  var _useSticky = useSticky(prefixCls),
      isSticky = _useSticky.isSticky,
      offsetHeader = _useSticky.offsetHeader,
      offsetSummary = _useSticky.offsetSummary; // Footer (Fix footer must fixed header)


  var fixFooter = (fixHeader || isSticky) && flattenColumns.some(function (v) {
    return !_.isUndefined(v.summaryRender) || !_.isUndefined(v.summaryTitle);
  }); // Scroll

  var scrollXStyle;
  var scrollYStyle;
  var scrollTableStyle;

  if (fixHeader) {
    scrollYStyle = {
      overflowY: 'scroll',
      maxHeight: scroll.y
    };
  }

  if (horizonScroll) {
    scrollXStyle = {
      overflowX: 'auto'
    };

    if (!fixHeader) {
      scrollYStyle = {
        overflowY: 'hidden'
      };
    }

    scrollTableStyle = {
      width: (scroll === null || scroll === void 0 ? void 0 : scroll.x) === true ? 'auto' : scroll === null || scroll === void 0 ? void 0 : scroll.x,
      minWidth: '100%'
    };
  }

  if (!fixHeader && !horizonScroll) {
    throw new Error('no scroll,quit!');
  }

  var onColumnResize = React.useCallback(function (columnKey, width) {
    if (isVisible(fullTableRef.current)) {
      updateColsWidths(function (widths) {
        if (widths.get(columnKey) !== width) {
          var newWidths = new Map(widths);
          newWidths.set(columnKey, width);
          return newWidths;
        }

        return widths;
      });
    }
  }, []);

  var _useTimeoutLock = useTimeoutLock(null),
      _useTimeoutLock2 = _slicedToArray(_useTimeoutLock, 2),
      setScrollTarget = _useTimeoutLock2[0],
      getScrollTarget = _useTimeoutLock2[1];

  function forceScroll(scrollLeft, target) {
    if (!target) {
      return;
    }

    if (typeof target === 'function') {
      target(scrollLeft);
    } else if (target.scrollLeft !== scrollLeft) {
      // eslint-disable-next-line no-param-reassign
      target.scrollLeft = scrollLeft;
    }
  }

  var onScroll = function onScroll(_ref3) {
    var currentTarget = _ref3.currentTarget,
        scrollLeft = _ref3.scrollLeft;
    var isRTL = direction === 'rtl';
    var mergedScrollLeft = typeof scrollLeft === 'number' ? scrollLeft : currentTarget.scrollLeft;
    var compareTarget = currentTarget || EMPTY_SCROLL_TARGET;

    if (!getScrollTarget() || getScrollTarget() === compareTarget) {
      var _scrollHeaderRef$curr, _stickyRef$current, _scrollBodyRef$curren;

      setScrollTarget(compareTarget); //forceScroll(mergedScrollLeft, scrollLineRef.current?.setScrollLeft);

      forceScroll(mergedScrollLeft, (_scrollHeaderRef$curr = scrollHeaderRef.current) === null || _scrollHeaderRef$curr === void 0 ? void 0 : _scrollHeaderRef$curr.setScrollLeft);
      forceScroll(mergedScrollLeft, scrollSummaryRef.current);
      forceScroll(mergedScrollLeft, (_stickyRef$current = stickyRef.current) === null || _stickyRef$current === void 0 ? void 0 : _stickyRef$current.setScrollLeft); // 虚拟滚动条,手动控制

      (_scrollBodyRef$curren = scrollBodyRef.current) === null || _scrollBodyRef$curren === void 0 ? void 0 : _scrollBodyRef$curren.setPosition({
        left: mergedScrollLeft
      });
    }

    if (currentTarget) {
      var scrollWidth = currentTarget.scrollWidth,
          clientWidth = currentTarget.clientWidth; // There is no space to scroll

      if (scrollWidth !== undefined && scrollWidth === clientWidth) {
        setPingedLeft(false);
        setPingedRight(false);
        return;
      }

      if (isRTL) {
        setPingedLeft(-mergedScrollLeft < scrollWidth - clientWidth);
        setPingedRight(-mergedScrollLeft > 0);
      } else {
        setPingedLeft(mergedScrollLeft > 0);
        setPingedRight(mergedScrollLeft < scrollWidth - clientWidth);
      }
    }
  };

  var triggerOnScroll = function triggerOnScroll() {
    if (horizonScroll && scrollBodyRef.current.el) {
      onScroll({
        currentTarget: scrollBodyRef.current.el
      });
    } else {
      setPingedLeft(false);
      setPingedRight(false);
    }
  };

  var onVirtualScroll = function onVirtualScroll(target, type) {
    var startIndex = Math.floor((target === null || target === void 0 ? void 0 : target.scrollTop) / itemHeight);
    if (lastStartIndex.current === startIndex && type !== 'reset') return;
    lastStartIndex.current = startIndex;
    var containerMaxSize = viewMaxNum.current;
    var endIndex = startIndex + 2 * containerMaxSize - 1;
    var currLen = mergedData.length; // 接近滚动到列表底部

    if (endIndex > currLen - 1) {
      endIndex = currLen - 1;
    }

    lastEndIndex.current = endIndex;

    if (startIndex <= containerMaxSize) {
      startIndex = 0;
    } else {
      startIndex = startIndex - containerMaxSize;
    }

    blankFill.current = {
      paddingTop: "".concat(startIndex * itemHeight, "px"),
      paddingBottom: "".concat((mergedData.length - 1 - endIndex) * itemHeight, "px")
    };
    setShowData({
      list: mergedData.slice(startIndex, endIndex + 1),
      lastStartIndex: startIndex
    });
  };

  var onFullTableResize = function onFullTableResize(_ref4) {
    var width = _ref4.width,
        height = _ref4.height;

    if (width !== componentWidth || height !== viewMaxNum.current) {
      var listMaxHeight = scrollBodyRef.current ? scrollBodyRef.current.offsetHeight - summaryHeight : height - summaryHeight;
      var listMaxCount = Math.ceil(listMaxHeight / itemHeight) + 1;
      viewMaxNum.current = listMaxCount;
      viewMaxHeight.current = listMaxHeight;
      triggerOnScroll();
      scrollBodyRef.current.prepareScrollbar();
      setComponentWidth(fullTableRef.current ? fullTableRef.current.offsetWidth : width);
    }
  };

  var mounted = React.useRef(false);
  useEffect(function () {
    if (mounted.current) {
      triggerOnScroll();
    }
  }, [horizonScroll, columns.length]);
  useDeepCompareEffect(function () {
    // 特殊处理,针对data的更新,需要强制进行虚拟列表计算
    if (mounted.current) {
      triggerOnScroll();

      if (viewMaxNum.current !== null) {
        onVirtualScroll(scrollBodyRef.current.el, 'reset');
      }
    }
  }, [data]);
  useEffect(function () {
    if (mounted.current) {
      var listMaxCount = Math.ceil(viewMaxHeight.current / itemHeight) + 1;
      viewMaxNum.current = listMaxCount;
      onVirtualScroll(scrollBodyRef.current.el, 'reset');
    }
  }, [itemHeight]);
  React.useEffect(function () {
    mounted.current = true;
  }, []); // ================== INTERNAL HOOKS ==================

  React.useEffect(function () {
    if (internalRefs) {
      internalRefs.body.current = scrollBodyRef.current;
      internalRefs.container.current = fullTableRef.current;
      internalRefs.bodyInner.current = bodyInnerRef.current;
    }
  }); // ====================== Render ======================

  var groupTableNode; // Header props

  var headerProps = {
    colWidths: colWidths,
    columCount: flattenColumns.length,
    stickyOffsets: stickyOffsets,
    onHeaderCell: onHeaderCell,
    onHeaderRow: onHeaderRow,
    onSummaryRow: onSummaryRow,
    fixHeader: fixHeader,
    scroll: scroll
  }; // Empty

  var emptyNode = React.useMemo(function () {
    if (hasData) {
      return null;
    }

    var _Node = typeof emptyText === 'function' ? emptyText() : emptyText;

    return /*#__PURE__*/React.createElement(ExtraRow, {
      expanded: true,
      className: "".concat(prefixCls, "-empty-placeholder"),
      prefixCls: prefixCls,
      colSpan: flattenColumns.length,
      isEmpty: true
    }, _Node);
  }, [hasData, emptyText]); // Body

  var body = /*#__PURE__*/React.createElement(Body, {
    data: showData,
    measureColumnWidth: fixHeader || horizonScroll || isSticky,
    getRowKey: getRowKey,
    onRow: onRow,
    onCell: onCell
  });

  if (fixHeader) {
    var bodyContent = /*#__PURE__*/React.createElement(Scrollbar, {
      style: _objectSpread(_objectSpread({
        width: '100%',
        height: '100%'
      }, scrollXStyle), scrollYStyle),
      trackSize: "10px",
      onScrollbarScroll: function onScrollbarScroll(target) {
        onScroll({
          currentTarget: target,
          scrollLeft: target.scrollLeft
        });

        if (viewMaxNum.current !== null) {
          onVirtualScroll(target);
        }
      },
      autoHide: true,
      onScrollbarStart: onScrollbarStart,
      onScrollbarStop: onScrollbarStop,
      onScrollbarScrollTimeout: 0,
      fixedOffset: {
        top: 36
      },
      className: classNames("".concat(prefixCls, "-body")),
      dataSource: mergedData,
      showData: showData,
      ref: scrollBodyRef
    }, /*#__PURE__*/React.createElement("div", {
      className: classNames("".concat(prefixCls, "-body-inner")),
      style: _objectSpread(_objectSpread(_objectSpread({}, scrollTableStyle), blankFill.current), {}, {
        marginBottom: fixFooter ? 33 : 0
      }),
      ref: bodyInnerRef
    }, body));
    headerProps.colWidths = flattenColumns.map(function (_ref5) {
      var width = _ref5.width;
      return width;
    }); // Fixed holder share the props

    var fixedHolderProps = _objectSpread(_objectSpread(_objectSpread({
      noData: !mergedData.length,
      maxContentScroll: horizonScroll && scroll.x === 'max-content'
    }, headerProps), columnContext), {}, {
      direction: direction,
      scrollTableStyle: scrollTableStyle
    });

    groupTableNode = /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(FixedHolderLine, _objectSpread(_objectSpread({}, fixedHolderProps), {}, {
      stickyTopOffset: offsetHeader,
      className: "".concat(prefixCls, "-header"),
      ref: scrollHeaderRef
    }), function (fixedHolderPassProps) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Header, _objectSpread({}, fixedHolderPassProps)));
    }), bodyContent, emptyNode, fixFooter && /*#__PURE__*/React.createElement(FixedHolder, _objectSpread(_objectSpread({}, fixedHolderProps), {}, {
      stickyBottomOffset: offsetSummary,
      className: "".concat(prefixCls, "-summary"),
      ref: scrollSummaryRef
    }), function (fixedHolderPassProps) {
      return /*#__PURE__*/React.createElement(Footer, _objectSpread({
        data: mergedData
      }, fixedHolderPassProps));
    }));
  }

  var ariaProps = pickAttrs(props, {
    aria: true,
    data: true
  });
  var fullTable = /*#__PURE__*/React.createElement("div", _objectSpread({
    className: classNames(prefixCls, className, (_classNames = {}, _defineProperty(_classNames, "".concat(prefixCls, "-rtl"), direction === 'rtl'), _defineProperty(_classNames, "".concat(prefixCls, "-ping-left"), pingedLeft), _defineProperty(_classNames, "".concat(prefixCls, "-ping-right"), pingedRight), _defineProperty(_classNames, "".concat(prefixCls, "-fixed-header"), fixHeader), _defineProperty(_classNames, "".concat(prefixCls, "-fixed-column"), fixColumn), _defineProperty(_classNames, "".concat(prefixCls, "-scroll-horizontal"), horizonScroll), _defineProperty(_classNames, "".concat(prefixCls, "-has-fix-left"), flattenColumns[0] && flattenColumns[0].fixed), _defineProperty(_classNames, "".concat(prefixCls, "-has-fix-right"), flattenColumns[flattenColumns.length - 1] && flattenColumns[flattenColumns.length - 1].fixed === 'right'), _classNames)),
    style: style,
    id: id,
    ref: fullTableRef
  }, ariaProps), /*#__PURE__*/React.createElement(MemoTableContent, {
    pingLeft: pingedLeft,
    pingRight: pingedRight,
    props: _objectSpread(_objectSpread({}, props), {}, {
      stickyOffsets: stickyOffsets
    })
  }, /*#__PURE__*/React.createElement("div", {
    ref: scrollBodyContainerRef,
    className: "".concat(prefixCls, "-container")
  }, groupTableNode)));

  if (horizonScroll) {
    fullTable = /*#__PURE__*/React.createElement(ResizeObserver, {
      onResize: onFullTableResize
    }, fullTable);
  }

  var TableContextValue = React.useMemo(function () {
    var _scrollBodyRef$curren2;

    return {
      prefixCls: prefixCls,
      direction: direction,
      scrollbarSize: 0,
      fixedInfoList: flattenColumns.map(function (_, colIndex) {
        return getCellFixedInfo(colIndex, colIndex, flattenColumns, stickyOffsets, direction);
      }),
      pingedLeft: pingedLeft,
      pingedRight: pingedRight,
      isScroll: (scrollBodyRef === null || scrollBodyRef === void 0 ? void 0 : (_scrollBodyRef$curren2 = scrollBodyRef.current) === null || _scrollBodyRef$curren2 === void 0 ? void 0 : _scrollBodyRef$curren2.scrolling) || false,
      getExtraState: getExtraState,
      selectedColor: selectedColor,
      onColumnResizeStart: onColumnResizeStart,
      onColumnResizeStop: onColumnResizeStop,
      sortableStore: sortableStore,
      sortableDispatch: sortableDispatch,
      summaryHeight: summaryHeight,
      itemHeight: itemHeight,
      viewMaxNum: viewMaxNum.current,
      viewMaxHeight: viewMaxHeight.current,
      lastEndIndex: lastEndIndex.current,
      cellExtraRender: cellExtraRender
    };
  }, [onColumnResizeStart, onColumnResizeStop, prefixCls, direction, flattenColumns, stickyOffsets, pingedLeft, pingedRight, getExtraState, selectedColor, sortableStore, sortableDispatch, summaryHeight, itemHeight, viewMaxNum, viewMaxHeight, lastEndIndex, cellExtraRender]);
  var ResizeContextValue = React.useMemo(function () {
    return {
      onColumnResize: onColumnResize
    };
  }, [onColumnResize]);
  var BodyContextValue = React.useMemo(function () {
    return _objectSpread({
      rowClassName: rowClassName
    }, columnContext);
  }, [columnContext]);
  var ExtraRowContextValue = React.useMemo(function () {
    return {
      componentWidth: componentWidth,
      fixHeader: fixHeader,
      fixColumn: fixColumn,
      horizonScroll: horizonScroll
    };
  }, [componentWidth, fixHeader, fixColumn, horizonScroll]);
  return /*#__PURE__*/React.createElement(TableContext.Provider, {
    value: TableContextValue
  }, /*#__PURE__*/React.createElement(BodyContext.Provider, {
    value: BodyContextValue
  }, /*#__PURE__*/React.createElement(ExtraRowContext.Provider, {
    value: ExtraRowContextValue
  }, /*#__PURE__*/React.createElement(ResizeContext.Provider, {
    value: ResizeContextValue
  }, fullTable))));
}

Table.defaultProps = {
  rowKey: 'key',
  prefixCls: 'kodo-ex-art-table',
  onColumnResizeStart: function onColumnResizeStart() {},
  onColumnResizeStop: function onColumnResizeStop() {},
  emptyText: function emptyText() {
    return 'no data';
  }
};
export default Table;