import React from 'react';
import type { Key, FixedType, CellEllipsisType, AlignType, DataIndex, RenderedCell, GetComponentProps } from './index';
interface ColumnSharedType<RecordType> {
    title?: React.ReactNode;
    summaryTitle?: React.ReactNode;
    key?: Key;
    className?: string;
    fixed?: FixedType;
    onHeaderCell?: GetComponentProps<ColumnsType<RecordType>[number]>;
    onSummaryCell?: GetComponentProps<ColumnsType<RecordType>[number]>;
    ellipsis?: CellEllipsisType;
    align?: AlignType;
}
export interface ColumnType<RecordType> extends ColumnSharedType<RecordType> {
    /**
     * 无效,后续扩展
     */
    colSpan?: number;
    dataIndex?: DataIndex;
    render?: (value: any, record: RecordType, index: number, columnIndex: number) => React.ReactNode | RenderedCell<RecordType>;
    summaryRender?: (data: RecordType) => React.ReactNode | RenderedCell<RecordType>;
    shouldCellUpdate?: (record: RecordType, prevRecord: RecordType) => boolean;
    /**
     * 用于标识是否自动放大单元格,用于计算fixedOffset
     */
    flex?: boolean;
    /**
     * 是否可以进行手动伸缩
     */
    resize?: any;
    /**
     * 是否可以拖拽进行手动排序
     */
    sortable?: any;
    /**
     * 无效,后续扩展
     */
    rowSpan?: number;
    width?: number | string;
    minWidth?: number | string;
    onCell?: any;
    /** @deprecated Please use `onCell` instead */
    onCellClick?: (record: RecordType, e: React.MouseEvent<HTMLElement>) => void;
}
export declare type ColumnsType<RecordType = unknown> = readonly ColumnType<RecordType>[];
export {};
