/// <reference types="react" />
/** 单元格模式 */
export declare enum Mode {
    'Editable' = 0,
    'Readonly' = 1
}
/** 行高 */
export declare type Size = 'small' | 'middle' | 'large';
export interface Config {
    /** 表格行高 */
    size?: Size;
    /** 单元格是否在focus状态 */
    isFocusing?: boolean;
    /** 单元格底部预留的absolute定位位置，用于select组件的getPopupContainer属性 */
    cell?: React.MutableRefObject<HTMLDivElement>;
    selectedCell?: {
        rowIndex: number;
        columnIndex: number;
    };
}
/** 行高对应的实际px值 */
export declare const CellHeight: Map<Size, string>;
export declare enum ValueType {
    'number' = 0,
    'date' = 1,
    'text' = 2
}
/** 读自定义渲染 */
export declare type ReadRender = (config: Config) => React.ReactNode;
/** 编辑自定义渲染（当cb回调参数非undefined时，会触发组件的EditableCell组件的onChange事件） */
export declare type EditRender<T> = (config: Config, cb: (newValue?: T) => void) => React.ReactNode;
export interface EditableCellProps<T> {
    /** 组件值   */
    value?: T;
    /**
     * 模式，只读/可编辑
     * @default           Mode.Editable
     */
    mode?: Mode;
    /**
     * 禁用
     * @default           false
     */
    disable?: boolean;
    /** 自定义编辑图标
     * @default           icon-bianji
     */
    editIcon?: React.ReactNode;
    /**
     * 读模式中，是否需要padding（编辑模式中无padding）
     * @default           true
     */
    readPadding?: boolean;
    /** 读自定义渲染 */
    readRender?: ReadRender;
    /** 编辑自定义渲染（可编辑模式下必填，否则不可编辑） */
    editRender?: EditRender<T>;
    /** 编辑组件change时的回调，使用cb退出编辑模式（当editRender中组件调用的cb参数非undefined时触发） */
    onChange?: (newValue: T, cb: () => void) => void;
    beforeEdit?: () => Promise<boolean>;
    /** 单元格所在行的序号 */
    rowIndex: number;
    /** 单元格所在列的序号 */
    columnIndex: number;
}
