"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Line = void 0;

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _TableContext = _interopRequireDefault(require("../context/TableContext"));

var _valueUtil = require("../utils/valueUtil");

var _fixUtil = require("../utils/fixUtil");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var Line = function Line(_ref) {
  var colWidths = _ref.colWidths,
      columns = _ref.columns,
      stickyOffsets = _ref.stickyOffsets,
      direction = _ref.direction,
      scrollTableStyle = _ref.scrollTableStyle,
      scrollBodyTranslateX = _ref.scrollBodyTranslateX;

  var _React$useContext = _react.default.useContext(_TableContext.default),
      prefixCls = _React$useContext.prefixCls,
      pingedLeft = _React$useContext.pingedLeft,
      pingedRight = _React$useContext.pingedRight;

  var cells = _react.default.useMemo(function () {
    return (0, _valueUtil.parseHeaderRows)(columns)[0];
  }, [columns]);

  var cellPrefixCls = "".concat(prefixCls, "-line");
  return /*#__PURE__*/_react.default.createElement("div", {
    className: "".concat(prefixCls, "-lines-inner"),
    style: _objectSpread({}, scrollTableStyle)
  }, cells.map(function (cell, index) {
    var _cell$column, _cell$column2, _classNames, _classNames3;

    // ====================== Fixed =======================
    var fixedInfo = (0, _fixUtil.getCellFixedInfo)(cell.colStart, cell.colEnd, columns, stickyOffsets, direction);
    var fixedStyle = {};
    var isFixLeft = typeof fixedInfo.fixLeft === 'number';
    var isFixRight = typeof fixedInfo.fixRight === 'number';

    var _ref2 = cell || {},
        column = _ref2.column;

    if (isFixLeft) {
      fixedStyle.position = 'sticky';
      fixedStyle.left = fixedInfo.fixLeft;
    }

    if (isFixRight) {
      fixedStyle.position = 'sticky';
      fixedStyle.right = fixedInfo.fixRight;
    }

    if (!isFixLeft && !isFixRight) {
      fixedStyle.transform = "translateX(-".concat(scrollBodyTranslateX, "px)");
    }

    var isResize = (column === null || column === void 0 ? void 0 : column.resize) !== false;
    return /*#__PURE__*/_react.default.createElement("div", {
      className: (0, _classnames.default)(cellPrefixCls, cell === null || cell === void 0 ? void 0 : cell.className),
      key: index,
      style: _objectSpread({
        width: colWidths[index],
        flex: (cell === null || cell === void 0 ? void 0 : (_cell$column = cell.column) === null || _cell$column === void 0 ? void 0 : _cell$column.flex) === false ? '0 0 auto' : '1 0 auto',
        minWidth: (cell === null || cell === void 0 ? void 0 : (_cell$column2 = cell.column) === null || _cell$column2 === void 0 ? void 0 : _cell$column2.minWidth) || 96
      }, fixedStyle)
    }, isResize && /*#__PURE__*/_react.default.createElement("div", {
      className: (0, _classnames.default)("".concat(cellPrefixCls, "-resize"))
    }), isFixLeft && !pingedLeft && fixedInfo.lastFixLeft && /*#__PURE__*/_react.default.createElement("div", {
      className: (0, _classnames.default)((_classNames = {}, _defineProperty(_classNames, "".concat(cellPrefixCls, "-fix-left"), isFixLeft), _defineProperty(_classNames, "".concat(cellPrefixCls, "-fix-left-first"), fixedInfo.firstFixLeft), _defineProperty(_classNames, "".concat(cellPrefixCls, "-fix-left-last-border"), fixedInfo.lastFixLeft), _defineProperty(_classNames, "".concat(cellPrefixCls, "-fix-sticky"), isFixLeft || isFixRight), _classNames))
    }), isFixLeft && pingedLeft && fixedInfo.lastFixLeft && /*#__PURE__*/_react.default.createElement("div", {
      className: (0, _classnames.default)(cellPrefixCls, _defineProperty({}, "".concat(cellPrefixCls, "-fix-left-last"), fixedInfo.lastFixLeft))
    }), isFixRight && !pingedRight && fixedInfo.firstFixRight && /*#__PURE__*/_react.default.createElement("div", {
      className: (0, _classnames.default)((_classNames3 = {}, _defineProperty(_classNames3, "".concat(cellPrefixCls, "-fix-right"), isFixRight), _defineProperty(_classNames3, "".concat(cellPrefixCls, "-fix-right-last"), fixedInfo.lastFixRight), _defineProperty(_classNames3, "".concat(cellPrefixCls, "-fix-right-first-border"), fixedInfo.firstFixRight), _defineProperty(_classNames3, "".concat(cellPrefixCls, "-fix-sticky"), isFixLeft || isFixRight), _classNames3))
    }), isFixRight && pingedRight && fixedInfo.firstFixRight && /*#__PURE__*/_react.default.createElement("div", {
      className: (0, _classnames.default)(cellPrefixCls, _defineProperty({}, "".concat(cellPrefixCls, "-fix-right-first"), fixedInfo.firstFixRight))
    }));
  }));
};

exports.Line = Line;